pub struct CacheHealthComponent { /* private fields */ }Expand description
Runtime component that registers the standard cache diagnostics check.
Implementations
Sourceimpl CacheHealthComponent
impl CacheHealthComponent
Sourcepub fn new(config: CacheConfig, cache: Arc<dyn CacheBackend>) -> Self
pub fn new(config: CacheConfig, cache: Arc<dyn CacheBackend>) -> Self
Creates a cache health component from static configuration and active backend.